@@ -1,4 +1,4 @@
-# Copyright 2010-2021 The pygit2 contributors
+# Copyright 2010-2023 The pygit2 contributors
 #
 # This file is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2,
@@ -59,7 +59,7 @@ def to_str(s):
     if type(s) is bytes:
         return s.decode()
 
-    raise TypeError('unexpected type "%s"' % repr(s))
+    raise TypeError(f'unexpected type "{repr(s)}"')
 
 
 def ptr_to_bytes(ptr_cdata):
